@@ -6,7 +6,7 @@
 
         Alex Buell <alex.buell@munted.eu>
 
-	Copyright (C) 2005 
+	Copyright (C) 2005,2016 
 	Helge Kreutzmann <debian@helgefjell.de>
 
         Version Author  Date            Comments
@@ -16,6 +16,7 @@
 	1.0.2	AIB	20010909	Added getphysicalmemory() call
 	1.0.3   KRE     20050328        Fix multicpu-detection without bogomips
 	1.0.4   KRE     20051118        Include <string.h>
+	1.0.5   KRE     20160918        Determine fastest CPU
 
         This is the PPC port of linuxinfo
 */
@@ -56,7 +57,11 @@ void GetHardwareInfo(int fd, struct hw_stat *hw)
 			strcpy(vendor, temp_string2);
 
 		if (!(strncmp(temp_string, "clock", strlen("clock"))))
+		{
+		    if (atoi(temp_string2) > megahertz)
+		    {
 			megahertz = atoi(temp_string2);
+		    }
 
 		if (!(strncmp(temp_string, "bogomips", strlen("bogomips"))))
 		{
